==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/subscriptions/SubscriptionKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.subscriptions;

import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.SubscriptionId;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of subscription.
 */
public class SubscriptionKeys implements KeyInfo<DefaultSubscription> {
    protected SubscriptionId identifier;
    /**
     * Returns the attribute identifier.
     *
     * @return identifier value of identifier
     */
    public SubscriptionId identifier() {
        return identifier;
    }

    /**
     * Sets the value to attribute identifier.
     *
     * @param identifier value of identifier
     */
    public void identifier(SubscriptionId identifier) {
        this.identifier = identifier;
    }


    @Override
    public int hashCode() {
        return Objects.hash(identifier);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof SubscriptionKeys) {
            SubscriptionKeys other = (SubscriptionKeys) obj;
            return
                Objects.equals(identifier, other.identifier);
        }
        return false;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/subscriptions/SubscriptionKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.subscriptions;

import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.SubscriptionId;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of subscription.
 */
public class SubscriptionKeys implements KeyInfo<DefaultSubscription> {
    protected SubscriptionId identifier;
    /**
     * Returns the attribute identifier.
     *
     * @return identifier value of identifier
     */
    public SubscriptionId identifier() {
        return identifier;
    }

    /**
     * Sets the value to attribute identifier.
     *
     * @param identifier value of identifier
     */
    public void identifier(SubscriptionId identifier) {
        this.identifier = identifier;
    }


    @Override
    public int hashCode() {
        return Objects.hash(identifier);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof SubscriptionKeys) {
            SubscriptionKeys other = (SubscriptionKeys) obj;
            return
                Objects.deepEquals(identifier, other.identifier);
        }
        return false;
    }
}
